## For Python 3 only 

# Release Candidate
%global __rc_ver %{nil}

%global fish_dir %{_datadir}/fish/vendor_functions.d
%global zsh_dir %{_datadir}/zsh/site-functions

# py3_shbang_flags is '-s' and causing issues with pip install.
%global py3_shebang_flags %(echo %py3_shebang_flags | sed s/s//)

Name:    salt
Version: 3006.9%{?__rc_ver}
Release: 3%{?dist}
Summary: A parallel remote execution system
Group:   System Environment/Daemons
License: ASL 2.0
URL:     https://saltproject.io/
Source0: %{pypi_source}
Source1: %{name}-proxy@.service
Source2: %{name}-master
Source3: %{name}-syndic
Source4: %{name}-minion
Source5: %{name}-api
Source6: %{name}-master.service
Source7: %{name}-syndic.service
Source8: %{name}-minion.service
Source9: %{name}-api.service
Source10: README.fedora
Source11: %{name}-common.logrotate
Source12: %{name}.bash
Source13: %{name}.fish
Source14: %{name}_common.fish
Source15: %{name}-call.fish
Source16: %{name}-cp.fish
Source17: %{name}-key.fish
Source18: %{name}-master.fish
Source19: %{name}-minion.fish
Source20: %{name}-run.fish
Source21: %{name}-syndic.fish

Patch0: contextvars.patch
Patch1: match_hostname.patch
Patch2: 0002-Hide-known-DeprecationWarning-related-to-PEP-594.patch
Patch3: 0001-Drop-versioned-certifi-dependency.patch
Patch4: 0001-Use-timezone-aware-datetime-objects-for-UTC-too.patch
Patch5: 0001-Fix-Python3.13-compatibility-regarding-urllib.parse-.patch
BuildArch: noarch

%ifarch %{ix86} x86_64
Requires: dmidecode
%endif

Requires: pciutils
Requires: which
Requires: dnf-utils
Requires: logrotate

BuildRequires: systemd-rpm-macros
BuildRequires: python3-devel

BuildRequires: ((python3dist(msgpack) < 0.5.5 or python3dist(msgpack) > 0.5.5) with python3dist(msgpack) >= 0.5)
BuildRequires: (python3dist(toml) if python3-devel < 3.11)
BuildRequires: pyproject-rpm-macros
BuildRequires: python3-devel
BuildRequires: python3-devel
BuildRequires: python3dist(distro) >= 1.0.1
BuildRequires: python3dist(jinja2)
BuildRequires: python3dist(jmespath)
BuildRequires: python3dist(looseversion)
BuildRequires: python3dist(markupsafe)
BuildRequires: python3dist(packaging) >= 21.3
BuildRequires: python3dist(pip) >= 19
BuildRequires: python3dist(psutil) >= 5
BuildRequires: python3dist(pycryptodomex) >= 3.9.8
BuildRequires: python3dist(pyyaml)
BuildRequires: python3dist(pyzmq) >= 20
BuildRequires: python3dist(requests) >= 1
BuildRequires: python3dist(setuptools) >= 40.8
BuildRequires: python3dist(wheel)

%description
Salt is a distributed remote execution system used to execute commands and
query data. It was developed in order to bring the best solutions found in
the world of remote execution together and make them better, faster and more
malleable. Salt accomplishes this via its ability to handle larger loads of
information, and not just dozens, but hundreds or even thousands of individual
servers, handle them quickly and through a simple and manageable interface.


%package    master
Summary:    Management component for salt, a parallel remote execution system
Group:      System Environment/Daemons
Requires:   %{name} = %{version}-%{release}
Requires:   python3-systemd

%description master
The Salt master is the central server to which all minions connect.
Supports Python 3.


%package    minion
Summary:    Client component for Salt, a parallel remote execution system
Group:      System Environment/Daemons
Requires:   %{name} = %{version}-%{release}

%description minion
The Salt minion is the agent component of Salt. It listens for instructions
from the master, runs jobs, and returns results back to the master.
Supports Python 3.


%package    syndic
Summary:    Master-of-master component for Salt, a parallel remote execution system
Group:      System Environment/Daemons
Requires:   %{name}-master = %{version}-%{release}

%description syndic
The Salt syndic is a master daemon which can receive instruction from a
higher-level master, allowing for tiered organization of your Salt
infrastructure.
Supports Python 3.


%package    api
Summary:    REST API for Salt, a parallel remote execution system
Group:      Applications/System
Requires:   %{name}-master = %{version}-%{release}
Requires:   python3-cherrypy >= 3.2.2

%description api
salt-api provides a REST interface to the Salt master.
Supports Python 3.


%package    cloud
Summary:    Cloud provisioner for Salt, a parallel remote execution system
Group:      Applications/System
Requires:   %{name}-master = %{version}-%{release}
Requires:   python3-libcloud

%description cloud
The salt-cloud tool provisions new cloud VMs, installs salt-minion on them, and
adds them to the master's collection of controllable minions.
Supports Python 3.


%package    ssh
Summary:    Agentless SSH-based version of Salt, a parallel remote execution system
Group:      Applications/System
Requires:   %{name} = %{version}-%{release}

%description ssh
The salt-ssh tool can run remote execution functions and states without the use
of an agent (salt-minion) service.
Supports Python 3.


%prep
%autosetup -p1


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files salt

# Add some directories
install -d -m 0755 %{buildroot}%{_var}/log/%{name}
touch %{buildroot}%{_var}/log/%{name}/minion
touch %{buildroot}%{_var}/log/%{name}/master
install -d -m 0755 %{buildroot}%{_var}/cache/%{name}
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/master.d
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/minion.d
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/pki
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/pki/master
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/pki/minion
install -d -m 0700 %{buildroot}%{_sysconfdir}/%{name}/cloud.conf.d
install -d -m 0700 %{buildroot}%{_sysconfdir}/%{name}/cloud.deploy.d
install -d -m 0700 %{buildroot}%{_sysconfdir}/%{name}/cloud.maps.d
install -d -m 0700 %{buildroot}%{_sysconfdir}/%{name}/cloud.profiles.d
install -d -m 0700 %{buildroot}%{_sysconfdir}/%{name}/cloud.providers.d
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/proxy.d

# Add the config files
install -p -m 0640 conf/minion %{buildroot}%{_sysconfdir}/%{name}/minion
install -p -m 0640 conf/master %{buildroot}%{_sysconfdir}/%{name}/master
install -p -m 0600 conf/cloud  %{buildroot}%{_sysconfdir}/%{name}/cloud
install -p -m 0640 conf/roster %{buildroot}%{_sysconfdir}/%{name}/roster
install -p -m 0640 conf/proxy  %{buildroot}%{_sysconfdir}/%{name}/proxy

# Add the unit files
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE6} %{buildroot}%{_unitdir}/
install -p -m 0644 %{SOURCE7} %{buildroot}%{_unitdir}/
install -p -m 0644 %{SOURCE8} %{buildroot}%{_unitdir}/
install -p -m 0644 %{SOURCE9} %{buildroot}%{_unitdir}/
install -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/

# Logrotate
install -p %{SOURCE10} .
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
install -p -m 0644 %{SOURCE11} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# Bash completion
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -p -m 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}.bash

# Fish completion (TBD remove -v)
mkdir -p %{buildroot}%{fish_dir}
install -p -m 0644  %{SOURCE13} %{buildroot}%{fish_dir}/%{name}.fish
install -p -m 0644  %{SOURCE14} %{buildroot}%{fish_dir}/%{name}_common.fish
install -p -m 0644  %{SOURCE15} %{buildroot}%{fish_dir}/%{name}-call.fish
install -p -m 0644  %{SOURCE16} %{buildroot}%{fish_dir}/%{name}-cp.fish
install -p -m 0644  %{SOURCE17} %{buildroot}%{fish_dir}/%{name}-key.fish
install -p -m 0644  %{SOURCE18} %{buildroot}%{fish_dir}/%{name}-master.fish
install -p -m 0644  %{SOURCE19} %{buildroot}%{fish_dir}/%{name}-minion.fish
install -p -m 0644  %{SOURCE20} %{buildroot}%{fish_dir}/%{name}-run.fish
install -p -m 0644  %{SOURCE21} %{buildroot}%{fish_dir}/%{name}-syndic.fish

# ZSH completion
mkdir -p %{buildroot}%{zsh_dir}
install -p -m 0644 pkg/common/%{name}.zsh %{buildroot}%{zsh_dir}/_%{name}


%check
%pyproject_check_import -t


%files -f %{pyproject_files}
%license LICENSE
%doc README.fedora
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/bash_completion.d/%{name}.bash
%{_var}/cache/%{name}
%{_var}/log/%{name}
%{_bindir}/spm
%doc %{_mandir}/man1/spm.1*
%dir %{zsh_dir}
%dir %{_sysconfdir}/%{name}/
%dir %{_sysconfdir}/%{name}/pki/
%{fish_dir}/%{name}*.fish
%{zsh_dir}/_%{name}
%{_bindir}/salt-pip

%files master
%doc %{_mandir}/man7/%{name}.7*
%doc %{_mandir}/man1/%{name}.1*
%doc %{_mandir}/man1/%{name}-cp.1*
%doc %{_mandir}/man1/%{name}-key.1*
%doc %{_mandir}/man1/%{name}-master.1*
%doc %{_mandir}/man1/%{name}-run.1*
%{_bindir}/%{name}
%{_bindir}/%{name}-cp
%{_bindir}/%{name}-key
%{_bindir}/%{name}-master
%{_bindir}/%{name}-run
%{_unitdir}/%{name}-master.service
%config(noreplace) %{_sysconfdir}/%{name}/master
%config(noreplace) %{_sysconfdir}/%{name}/master.d
%config(noreplace) %{_sysconfdir}/%{name}/pki/master

%files minion
%doc %{_mandir}/man1/%{name}-call.1*
%doc %{_mandir}/man1/%{name}-minion.1*
%doc %{_mandir}/man1/%{name}-proxy.1*
%{_bindir}/%{name}-minion
%{_bindir}/%{name}-call
%{_bindir}/%{name}-proxy
%{_unitdir}/%{name}-minion.service
%{_unitdir}/%{name}-proxy@.service
%config(noreplace) %{_sysconfdir}/%{name}/minion
%config(noreplace) %{_sysconfdir}/%{name}/proxy
%config(noreplace) %{_sysconfdir}/%{name}/minion.d
%config(noreplace) %{_sysconfdir}/%{name}/pki/minion

%files syndic
%doc %{_mandir}/man1/%{name}-syndic.1*
%{_bindir}/%{name}-syndic
%{_unitdir}/%{name}-syndic.service

%files api
%doc %{_mandir}/man1/%{name}-api.1*
%{_bindir}/%{name}-api
%{_unitdir}/%{name}-api.service

%files cloud
%doc %{_mandir}/man1/%{name}-cloud.1*
%{_bindir}/%{name}-cloud
%{_sysconfdir}/%{name}/cloud.conf.d
%{_sysconfdir}/%{name}/cloud.deploy.d
%{_sysconfdir}/%{name}/cloud.maps.d
%{_sysconfdir}/%{name}/cloud.profiles.d
%{_sysconfdir}/%{name}/cloud.providers.d
%config(noreplace) %{_sysconfdir}/%{name}/cloud

%files ssh
%doc %{_mandir}/man1/%{name}-ssh.1*
%{_bindir}/%{name}-ssh
%config(noreplace) %{_sysconfdir}/%{name}/roster


# assumes systemd for RHEL 7 & 8
%preun master
%systemd_preun %{name}-syndic.service

%preun minion
%systemd_preun %{name}-minion.service

%preun api
%systemd_preun %{name}-api.service

%post master
%systemd_post %{name}-master.service

%post syndic
%systemd_post %{name}-syndic.service

%post minion
%systemd_post %{name}-minion.service

%post api
%systemd_post %{name}-api.service

%postun master
%systemd_postun_with_restart %{name}-master.service

%postun syndic
%systemd_postun_with_restart %{name}-syndic.service

%postun minion
%systemd_postun_with_restart %{name}-minion.service

%postun api
%systemd_postun_with_restart %{name}-api.service


%changelog
* Fri Nov 22 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-salt.git

* Fri Nov 22 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c7a05e4
- version 3006.9-3

* Thu Nov 21 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a9fd443
- debian: drop python3-boto

* Thu Nov 21 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c78ea29
- Support for Noble build

* Thu Nov 21 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c61bae5
- Drop TravisCI

* Thu Sep 19 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 88c424f
- version 3006.9-2

* Thu Sep 19 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0117323
- ci: test installing in R4.2 dom0 too

* Thu Sep 19 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e2df3a5
- Relax 'requests' dependency

* Wed Sep 18 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 517ac0f
- Include patched salt in VM too

* Wed Sep 18 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d4feb6e
- Backport patch fixing Python 3.13 compat

* Sat Aug 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 81b554b
- Fix some of the DeprecationWarning about datetime.datetime.utcnow

* Sat Aug 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8504564
- Adjust dependencies to be compatible with F41

* Sat Aug 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 18b0420
- version 3006.9-1

* Sat Aug 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - df9b241
- Build for f41 dom0 too

* Sat Aug 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3079966
- version 3006.9-1

* Sat Aug 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9734088
- ci: switch to R4.3

* Mon Feb 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8a26a9e
- version 3006.5-1

* Mon Feb 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d7adbf9
- debian: drop some build depends used for tests only

* Mon Feb 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8eadf89
- Drop patches included upstream already

* Mon Feb 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d4df3b3
- Switch tarball check to signature

* Tue Jan 23 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - df941df
- Enable build for trixie

* Fri Dec 01 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7a33f4c
- version 3006.4-2

* Wed Nov 29 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d9a8a44
- Update to 3006.4

* Wed Aug 23 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 394a637
- version 3006.2-2

* Mon Jul 03 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c8606cd
- version 3006.1-2

* Sat Jul 01 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f530785
- Backport more patches to fix regression

* Thu Jun 29 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1aa88dc
- debian: drop non-standard user patch

* Thu Jun 29 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6fa3825
- debian: include backports from Fedora package

* Thu Jun 29 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b23538c
- Update Debian packaging to 3006.1-1

* Wed Jun 28 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 72979be
- Commit unmodified Debian's salt 3004.1+dfsg-2

* Wed Jun 28 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ab55f80
- Build for fc38 too

* Thu Jun 22 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 54d7570
- Backport a fix for salt-ssh exit code

* Thu Jun 22 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 882d78e
- Deal with DeprecationWarning when running on py3.11

* Wed Jun 21 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5870cde
- Update to 3006.1

* Wed Feb 01 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 04099e4
- version 3005.1-4

* Wed Feb 01 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a0a11d3
- rpm: do not use dynamic BuildRequires

* Wed Feb 01 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8bcad42
- ci: test vm build too

* Wed Feb 01 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5ca1131
- Backport patch for Python 3.11 support

* Tue Jan 31 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f8e718a
- Import fresh salt-3005.1-1.fc37.src

* Mon May 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1745c3d
- travis: use included configs

* Mon May 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cf2ed70
- Limit build to dom0+vm fc32 only

* Sun May 17 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 86298d7
- Update to 3000.3

* Sun May 03 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9cd5908
- Temporarly allow build for VM

* Sun May 03 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - da75e78
- Update to version 3000.2

* Mon Apr 13 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 2b442cc
- Fix Python 3.8 from upstream code.

* Sun Apr 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 15ef466
- Update to salt-3000.1 and sync with Fedora

* Sun Apr 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - bda0c26
- Create .spec.in, set epoch to 1000 and update Makefile

* Sat Dec 21 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 58ae950
- Workaround for incompatible python3-tornado library

* Fri Dec 20 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3326b6e
- Add travis

* Fri Dec 20 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f4be0b3
- Add qubes-builder integration

* Fri Dec 20 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 31a8e59
- Update to 2019.2.2

